//-*-c++-*-
#ifndef TULIP_STRINGPROXY_H
#define TULIP_STRINGPROXY_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "PropertyProxy.h"
#include "MethodFactory.h"
#include "TemplateFactory.h"
#include "String.h"
class PropertyContext;
/** \addtogroup properties */ 
/*\@{*/
class TLP_SCOPE StringProxy:public PropertyProxy<StringType,StringType, String>{ 

  friend class String;

public :
  StringProxy (SuperGraph *);
  ~StringProxy();
  PProxy* clonePrototype(SuperGraph *, std::string );
  void copy( const node, const node, PProxy * );
  void copy( const edge, const edge, PProxy * );

protected:
  void reset_handler();
  void recompute_handler();  
};
/*\@}*/
#endif
